==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/AverageDirectionalIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AverageDirectionalIndexIndicatorDescription } from "./AverageDirectionalIndexIndicatorDescription";
/**
 * @hidden
 */
export let AverageDirectionalIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class AverageDirectionalIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (AverageDirectionalIndexIndicatorDescriptionMetadata.a == null) {
                AverageDirectionalIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AverageDirectionalIndexIndicatorDescriptionMetadata.c(AverageDirectionalIndexIndicatorDescriptionMetadata.a);
            }
            if (a.j(AverageDirectionalIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(AverageDirectionalIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            AverageDirectionalIndexIndicatorDescriptionMetadata.b(a);
            a.aa("AverageDirectionalIndexIndicator", () => new AverageDirectionalIndexIndicatorDescription());
            a.z("AverageDirectionalIndexIndicator", AverageDirectionalIndexIndicatorDescriptionMetadata.a);
        }
    }
    AverageDirectionalIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(AverageDirectionalIndexIndicatorDescriptionMetadata, 'AverageDirectionalIndexIndicatorDescriptionMetadata');
    AverageDirectionalIndexIndicatorDescriptionMetadata.a = null;
    return AverageDirectionalIndexIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AverageDirectionalIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AverageDirectionalIndexIndicatorDescription } from "./AverageDirectionalIndexIndicatorDescription";
/**
 * @hidden
 */
export let AverageDirectionalIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class AverageDirectionalIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (AverageDirectionalIndexIndicatorDescriptionMetadata.a == null) {
                AverageDirectionalIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AverageDirectionalIndexIndicatorDescriptionMetadata.c(AverageDirectionalIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(AverageDirectionalIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(AverageDirectionalIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            AverageDirectionalIndexIndicatorDescriptionMetadata.b(a);
            a.ac("AverageDirectionalIndexIndicator", () => new AverageDirectionalIndexIndicatorDescription());
            a.ab("AverageDirectionalIndexIndicator", AverageDirectionalIndexIndicatorDescriptionMetadata.a);
        }
    }
    AverageDirectionalIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(AverageDirectionalIndexIndicatorDescriptionMetadata, 'AverageDirectionalIndexIndicatorDescriptionMetadata');
    AverageDirectionalIndexIndicatorDescriptionMetadata.a = null;
    return AverageDirectionalIndexIndicatorDescriptionMetadata;
})();
